#
# spec file for package xset
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xset
Version:        1.2.5
Release:        2.7
Summary:        User preference utility for X
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmuu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
This program is used to set various user preference options of the
display.

%prep
%autosetup

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xset
%{_mandir}/man1/xset.1%{?ext_man}

%changelog
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Disable building with libXfontcache. xorg-server 1.6 removed the
  corresponding feature, and it seems unlikely and unusual for
  anyone to e.g. ssh from an old Xorg system to a contemporary
  SUSE to attempt to run the (undocumented) `xset fc` command.
* Sun Dec  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.5
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Use the real name of the DPMS extension in messages & man page
  * gitlab CI: add a basic build test
  * Fix spelling/wording issues
  * gitlab CI: stop requiring Signed-off-by in commits
  * Variable scope reduction as recommended by cppcheck
  * Remove unnecessary casts
  * Remove unnecessary check for NULL pointer before calling free()
  * set_pixels: Mark pixels parameter as const
  * Use C99 designated struct initializers
  * configure: Make xf86misc support disabled by default
* Sat May  1 2021 Dirk Müller <dmueller@suse.com>
- modernize spec-file (move license to licensedir)
* Mon Jun 24 2019 Stefan Dirsch <sndirsch@suse.com>
- no longer require legacy extension xf86miscproto; no longer
  provided by xorgproto-2019.1 by default
* Wed Apr  4 2018 sndirsch@suse.com
- Update to version 1.2.4
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * autogen.sh: use quoted string variables
  * Include unistd.h for usleep() if HAVE_USLEEP
  * Fix one last warning about usage() format string.
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
- supersedes U_xset_fix-warning-about-usage-format-string.patch
* Mon Nov 20 2017 zaitor@opensuse.org
- Add U_xset_fix-warning-about-usage-format-string.patch: Fix one
  last warning about usage() format string.
* Sat Aug 17 2013 zaitor@opensuse.org
- Update to version 1.2.3:
  + Pass buf size to on_or_off instead of just assuming it is big
    enough.
  + Add -version flag.
  + Fix integer sign/size conversion warnings from clang.
  + Add printf attribute to usage function and fix warnings it
    causes.
  + Fix gcc warnings about discarded const qualifiers.
  + Combine error message strings.
  + Combine usage message strings.
  + Drop usleep fallbacks for ancient OS versions.
  + Remove unneeded include of windows.h on WIN32.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.2.2:
  + Remove direct call to Solaris nanosleep system call
  + Mark error() & usage() functions as _X_NORETURN
  + Give better error for "xset dpms force" without argument
  + Print pixel colors in hex not decimal
  + Man page fixes.
  + Build system fixes.
- Add pkgconfig(xproto) BuildRequires: new upstream dependency.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xset from xorg-x11. Initial version: 1.2.1.
